@@ -21,14 +21,28 @@
 #undef TOTAL_MEMORY_SYMBOL
 #undef MBSTAT_SYMBOL
 
-/*
- * solaris cc doesn't like our use of inline. Until we figure out why,
- * turn of inline.
- */
-#ifndef __GNUC__
-#  define NETSNMP_NO_INLINE 1
-#endif
+#define UDP_ADDRESSES_IN_HOST_ORDER 1
+#define UDP_PORTS_IN_HOST_ORDER 1
+#define TCP_PORTS_IN_HOST_ORDER 1
 
 /* get some required prototypes (strtok_r) from include files */
 #define __EXTENSIONS__
 
+/* define the extra mib modules that are supported */
+#define NETSNMP_INCLUDE_HOST_RESOURCES
+#ifdef NETSNMP_ENABLE_MFD_REWRITES
+#define NETSNMP_INCLUDE_IFTABLE_REWRITES
+#endif
+
+/* Solaris 2.6+ */
+#define _SLASH_PROC_METHOD_ 1
+
+/* Solaris 7+ */
+#define NETSNMP_DONT_USE_NLIST 1
+
+/*
+ * NEW_MIB_COMPLIANT is a define used in Solaris 10U4+ to enable additional
+ * MIB information (it affects the structs in <inet/mib2.h>)
+ */
+
+#define NEW_MIB_COMPLIANT
